@@ -7,7 +7,7 @@
 #   which they can be run via Filter::Crypto::Decrypt.
 #
 # COPYRIGHT
-#   Copyright (C) 2004-2009, 2012-2013 Steve Hay.  All rights reserved.
+#   Copyright (C) 2004-2009, 2012-2014 Steve Hay.  All rights reserved.
 #
 # LICENCE
 #   You may distribute under the terms of either the GNU General Public License
@@ -17,7 +17,7 @@
 
 package Filter::Crypto::CryptFile;
 
-use 5.006000;
+use 5.008001;
 
 use strict;
 use warnings;
@@ -55,7 +55,7 @@ BEGIN {
         $ErrStr
     );
 
-    $VERSION = '2.03';
+    $VERSION = '2.05';
 
     XSLoader::load(__PACKAGE__, $VERSION);
 }
@@ -73,7 +73,7 @@ sub AUTOLOAD {
     our $AUTOLOAD;
 
     # Get the name of the constant to generate a subroutine for.
-    (my $constant = $AUTOLOAD) =~ s/^.*:://;
+    (my $constant = $AUTOLOAD) =~ s/^.*:://o;
 
     # Avoid deep recursion on AUTOLOAD() if constant() is not defined.
     croak('Unexpected error in AUTOLOAD(): constant() is not defined')
@@ -96,6 +96,7 @@ sub AUTOLOAD {
 
 sub crypt_file($;$$) {
     $ErrStr = '';
+    my $num_bytes = 0;
 
     if ( @_ == 1 or
         (@_ == 2 and (not defined $_[1] or $_[1] eq '' or
@@ -132,7 +133,7 @@ sub crypt_file($;$$) {
         my $crypt_mode = (@_ == 2 and defined $_[1] and $_[1] ne '')
                          ? $_[1] : CRYPT_MODE_AUTO();
 
-        unless (_crypt_fh($fh, $crypt_mode)) {
+        unless (_crypt_fh($fh, $crypt_mode, $num_bytes)) {
             local($!, $^E);
             $opened ? close $fh : $flocked ? flock $fh, LOCK_UN : 1;
             return;
@@ -231,7 +232,7 @@ sub crypt_file($;$$) {
             $crypt_mode = CRYPT_MODE_AUTO();
         }
 
-        unless (_crypt_fhs($in_fh, $out_fh, $crypt_mode)) {
+        unless (_crypt_fhs($in_fh, $out_fh, $crypt_mode, $num_bytes)) {
             local($!, $^E);
             $in_opened  ? close $in_fh
                         : $in_flocked  ? flock $in_fh,  LOCK_UN : 1;
@@ -261,7 +262,7 @@ sub crypt_file($;$$) {
         }
     }
 
-    return 1;
+    return $num_bytes ? $num_bytes : '0E0';
 }
 
 #===============================================================================
@@ -391,8 +392,10 @@ then the data is presumed to be in an encrypted state already so the mode will
 be set to C<CRYPT_MODE_DECRYPT>; otherwise the mode will be set to
 C<CRYPT_MODE_ENCRYPT>.
 
-Returns 1 on success, or a false value (namely, the undefined value in scalar
-context or the empty list in list context) and sets $ErrStr on failure.
+On success, returns the number of bytes written (which could be zero if the
+input was already in the requested state, in which case the special "zero but
+true" value will be returned); on failure returns the undefined value (in scalar
+context) or the empty list (in list context) and sets $ErrStr.
 
 =back
 
@@ -882,9 +885,9 @@ L<Filter::Crypto>.
 
 =head1 ACKNOWLEDGEMENTS
 
-The C<_PRNGInit()> and C<_GetRandNum()> functions used by the XS code are based
-on (code taken from) the C<ssl_rand_seed()> and C<ssl_rand_choosenum()>
-functions in mod_ssl (version 2.8.19-1.3.31).
+The C<FilterCrypto_PRNGInit()> and C<FilterCrypto_GetRandNum()> functions used
+by the XS code are based on code taken from the C<ssl_rand_seed()> and
+C<ssl_rand_choosenum()> functions in Apache httpd (version 2.4.9).
 
 Thanks to Steve Henson for help with performing PBE and PKCS#5 v2.0 key
 derivation with arbitrary ciphers and non-default key lengths using the OpenSSL
@@ -896,7 +899,7 @@ Steve Hay E<lt>shay@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2004-2009, 2012-2013 Steve Hay.  All rights reserved.
+Copyright (C) 2004-2009, 2012-2014 Steve Hay.  All rights reserved.
 
 =head1 LICENCE
 
@@ -906,11 +909,11 @@ License or the Artistic License, as specified in the F<LICENCE> file.
 
 =head1 VERSION
 
-Version 2.03
+Version 2.05
 
 =head1 DATE
 
-08 Jul 2013
+16 May 2014
 
 =head1 HISTORY
 
